Stan Math Library: stan/math/prim/mat/fun/sort_indices_asc.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
sort_indices_asc.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/mat/fun/sort_indices.hpp>`
`#include <algorithm>`
`#include <iostream>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename C >
std::vector< int > | stan::math::sort_indices_asc (const C &xs)
| Return a sorted copy of the argument container in ascending order. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.